<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="nl" sourcelanguage="en">
  <context>
    <name>CmdCreateSpreadsheet</name>
    <message>
      <source>Spreadsheet</source>
      <translation>Rekenblad</translation>
    </message>
    <message>
      <source>Create spreadsheet</source>
      <translation>Rekenblad aanmaken</translation>
    </message>
    <message>
      <source>Create a new spreadsheet</source>
      <translation>Een nieuw rekenblad aanmaken</translation>
    </message>
  </context>
  <context>
    <name>CmdSpreadsheetAlignBottom</name>
    <message>
      <source>Spreadsheet</source>
      <translation>Rekenblad</translation>
    </message>
    <message>
      <source>Align bottom</source>
      <translation>Onderzijde uitlijnen</translation>
    </message>
    <message>
      <source>Bottom-align contents of selected cells</source>
      <translation>Eigenschappen 'onderzijde uitlijnen' van geselecteerde cellen</translation>
    </message>
  </context>
  <context>
    <name>CmdSpreadsheetAlignCenter</name>
    <message>
      <source>Spreadsheet</source>
      <translation>Rekenblad</translation>
    </message>
    <message>
      <source>Align center</source>
      <translation>Midden uitlijnen</translation>
    </message>
    <message>
      <source>Center-align contents of selected cells</source>
      <translation>Eigenschappen 'midden uitlijnen' van geselecteerde cellen</translation>
    </message>
  </context>
  <context>
    <name>CmdSpreadsheetAlignLeft</name>
    <message>
      <source>Spreadsheet</source>
      <translation>Rekenblad</translation>
    </message>
    <message>
      <source>Align left</source>
      <translation>Links uitlijnen</translation>
    </message>
    <message>
      <source>Left-align contents of selected cells</source>
      <translation>Eigenschappen 'links uitlijnen' van geselecteerde cellen</translation>
    </message>
  </context>
  <context>
    <name>CmdSpreadsheetAlignRight</name>
    <message>
      <source>Spreadsheet</source>
      <translation>Rekenblad</translation>
    </message>
    <message>
      <source>Align right</source>
      <translation>Rechts uitlijnen</translation>
    </message>
    <message>
      <source>Right-align contents of selected cells</source>
      <translation>Eigenschappen 'rechts uitlijnen' van geselecteerde cellen</translation>
    </message>
  </context>
  <context>
    <name>CmdSpreadsheetAlignTop</name>
    <message>
      <source>Spreadsheet</source>
      <translation>Rekenblad</translation>
    </message>
    <message>
      <source>Align top</source>
      <translation>Bovenaan uitlijnen</translation>
    </message>
    <message>
      <source>Top-align contents of selected cells</source>
      <translation>Eigenschappen 'bovenzijde uitlijnen' van geselecteerde cellen</translation>
    </message>
  </context>
  <context>
    <name>CmdSpreadsheetAlignVCenter</name>
    <message>
      <source>Spreadsheet</source>
      <translation>Rekenblad</translation>
    </message>
    <message>
      <source>Vertically center-align</source>
      <translation>Verticaal centreren</translation>
    </message>
    <message>
      <source>Vertically center-align contents of selected cells</source>
      <translation>Eigenschappen 'vertikaal uitlijnen' van geselecteerde cellen</translation>
    </message>
  </context>
  <context>
    <name>CmdSpreadsheetExport</name>
    <message>
      <source>Spreadsheet</source>
      <translation>Rekenblad</translation>
    </message>
    <message>
      <source>Export spreadsheet</source>
      <translation>Rekenblad exporteren</translation>
    </message>
    <message>
      <source>Export spreadsheet to CSV file</source>
      <translation>Het rekenblad naar CSV-bestand exporteren</translation>
    </message>
  </context>
  <context>
    <name>CmdSpreadsheetImport</name>
    <message>
      <source>Spreadsheet</source>
      <translation>Rekenblad</translation>
    </message>
    <message>
      <source>Import spreadsheet</source>
      <translation>Rekenblad importeren</translation>
    </message>
    <message>
      <source>Import CSV file into spreadsheet</source>
      <translation>Een CSV-bestand als rekenblad importeren</translation>
    </message>
  </context>
  <context>
    <name>CmdSpreadsheetMergeCells</name>
    <message>
      <source>Spreadsheet</source>
      <translation>Rekenblad</translation>
    </message>
    <message>
      <source>Merge cells</source>
      <translation>Cellen samenvoegen</translation>
    </message>
    <message>
      <source>Merge selected cells</source>
      <translation>Geselecteerde cellen samenvoegen</translation>
    </message>
  </context>
  <context>
    <name>CmdSpreadsheetSetAlias</name>
    <message>
      <source>Spreadsheet</source>
      <translation>Rekenblad</translation>
    </message>
    <message>
      <source>Set alias</source>
      <translation>Alias instellen</translation>
    </message>
    <message>
      <source>Set alias for selected cell</source>
      <translation>Een alias instellen voor de geselecteerde cel</translation>
    </message>
  </context>
  <context>
    <name>CmdSpreadsheetSplitCell</name>
    <message>
      <source>Spreadsheet</source>
      <translation>Rekenblad</translation>
    </message>
    <message>
      <source>Split cell</source>
      <translation>Cel splitsen</translation>
    </message>
    <message>
      <source>Split previously merged cells</source>
      <translation>Eerder samengevoegde cellen splitsen</translation>
    </message>
  </context>
  <context>
    <name>CmdSpreadsheetStyleBold</name>
    <message>
      <source>Spreadsheet</source>
      <translation>Rekenblad</translation>
    </message>
    <message>
      <source>Bold text</source>
      <translation>Vette tekst</translation>
    </message>
    <message>
      <source>Set text in selected cells bold</source>
      <translation>Tekst in geselecteerde cellen vet instellen</translation>
    </message>
  </context>
  <context>
    <name>CmdSpreadsheetStyleItalic</name>
    <message>
      <source>Spreadsheet</source>
      <translation>Rekenblad</translation>
    </message>
    <message>
      <source>Italic text</source>
      <translation>Cursieve tekst</translation>
    </message>
    <message>
      <source>Set text in selected cells italic</source>
      <translation>Tekst in geselecteerde cellen cursief instellen</translation>
    </message>
  </context>
  <context>
    <name>CmdSpreadsheetStyleUnderline</name>
    <message>
      <source>Spreadsheet</source>
      <translation>Rekenblad</translation>
    </message>
    <message>
      <source>Underline text</source>
      <translation>Tekst onderlijnen</translation>
    </message>
    <message>
      <source>Underline text in selected cells</source>
      <translation>Tekst met onderstreping in geselecteerde cellen instellen</translation>
    </message>
  </context>
  <context>
    <name>ColorPickerPopup</name>
    <message>
      <source>Custom Color</source>
      <translation>Aangepaste kleur</translation>
    </message>
  </context>
  <context>
    <name>Command</name>
    <message>
      <source>Merge cells</source>
      <translation>Cellen samenvoegen</translation>
    </message>
    <message>
      <source>Split cell</source>
      <translation>Cel splitsen</translation>
    </message>
    <message>
      <source>Left-align cell</source>
      <translation type="unfinished">Left-align cell</translation>
    </message>
    <message>
      <source>Center cell</source>
      <translation type="unfinished">Center cell</translation>
    </message>
    <message>
      <source>Right-align cell</source>
      <translation type="unfinished">Right-align cell</translation>
    </message>
    <message>
      <source>Top-align cell</source>
      <translation type="unfinished">Top-align cell</translation>
    </message>
    <message>
      <source>Bottom-align cell</source>
      <translation type="unfinished">Bottom-align cell</translation>
    </message>
    <message>
      <source>Vertically center cells</source>
      <translation>Cellen verticaal centreren</translation>
    </message>
    <message>
      <source>Set bold text</source>
      <translation type="unfinished">Set bold text</translation>
    </message>
    <message>
      <source>Set italic text</source>
      <translation>Cursieve tekst instellen</translation>
    </message>
    <message>
      <source>Set underline text</source>
      <translation type="unfinished">Set underline text</translation>
    </message>
    <message>
      <source>Create Spreadsheet</source>
      <translation type="unfinished">Create Spreadsheet</translation>
    </message>
    <message>
      <source>Set cell properties</source>
      <translation>Celeigenschappen instellen</translation>
    </message>
    <message>
      <source>Edit cell</source>
      <translation>Cel bewerken</translation>
    </message>
    <message>
      <source>Insert rows</source>
      <translation>Rijen invoegen</translation>
    </message>
    <message>
      <source>Remove rows</source>
      <translation>Rijen verwijderen</translation>
    </message>
    <message>
      <source>Insert columns</source>
      <translation>Kolommen invoegen</translation>
    </message>
    <message>
      <source>Clear cell(s)</source>
      <translation type="unfinished">Clear cell(s)</translation>
    </message>
    <message>
      <source>Set foreground color</source>
      <translation>Voorgrondkleur instellen</translation>
    </message>
    <message>
      <source>Set background color</source>
      <translation>Achtergrondkleur instellen</translation>
    </message>
  </context>
  <context>
    <name>PropertiesDialog</name>
    <message>
      <source>Cell properties</source>
      <translation>Celeigenschappen</translation>
    </message>
    <message>
      <source>&amp;Color</source>
      <translation>&amp;Kleur</translation>
    </message>
    <message>
      <source>Text</source>
      <translation>Tekst</translation>
    </message>
    <message>
      <source>Background</source>
      <translation>Achtergrond</translation>
    </message>
    <message>
      <source>&amp;Alignment</source>
      <translation>&amp; Uitlijning</translation>
    </message>
    <message>
      <source>Horizontal</source>
      <translation>Horizontaal</translation>
    </message>
    <message>
      <source>Left</source>
      <translation>Links</translation>
    </message>
    <message>
      <source>Center</source>
      <translation>Middelpunt</translation>
    </message>
    <message>
      <source>Right</source>
      <translation>Rechts</translation>
    </message>
    <message>
      <source>Vertical</source>
      <translation>Verticaal</translation>
    </message>
    <message>
      <source>Top</source>
      <translation>Boven</translation>
    </message>
    <message>
      <source>Bottom</source>
      <translation>Onder</translation>
    </message>
    <message>
      <source>&amp;Style</source>
      <translation>&amp;Stijl</translation>
    </message>
    <message>
      <source>Bold</source>
      <translation>Vet</translation>
    </message>
    <message>
      <source>Italic</source>
      <translation>Cursief</translation>
    </message>
    <message>
      <source>Underline</source>
      <translation>Onderstrepen</translation>
    </message>
    <message>
      <source>&amp;Display unit</source>
      <translation>&amp; Beeldscherm</translation>
    </message>
    <message>
      <source>Unit string</source>
      <translation>Eenheid tekenreeks</translation>
    </message>
    <message>
      <source>A&amp;lias</source>
      <translation>A&amp;lias</translation>
    </message>
    <message>
      <source>Alias for this cell</source>
      <translation>Alias voor deze cel</translation>
    </message>
  </context>
  <context>
    <name>QObject</name>
    <message>
      <source>All (*)</source>
      <translation>Alle (*)</translation>
    </message>
    <message>
      <source>Import file</source>
      <translation>Bestand importeren</translation>
    </message>
    <message>
      <source>Export file</source>
      <translation>Bestand exporteren</translation>
    </message>
    <message>
      <source>Show spreadsheet</source>
      <translation>Rekenblad tonen</translation>
    </message>
    <message>
      <source>Set cell(s) foreground color</source>
      <translation>Zet de voorgrondkleur van de cel(len) op</translation>
    </message>
    <message>
      <source>Sets the Spreadsheet cell(s) foreground color</source>
      <translation>Stelt de voorgrondkleur van de Spreadsheet-cel(len) op</translation>
    </message>
    <message>
      <source>Set cell(s) background color</source>
      <translation>Zet de achtergrondkleur van de cel(len) op</translation>
    </message>
    <message>
      <source>Sets the Spreadsheet cell(s) background color</source>
      <translation>Stelt de achtergrondkleur van de Spreadsheet-cel(len) op</translation>
    </message>
    <message>
      <source>Spreadsheet</source>
      <translation>Rekenblad</translation>
    </message>
    <message>
      <source>Spreadsheet does not support range selection when pasting.
Please select one cell only.</source>
      <translation>Rekenblad ondersteunt geen bereikselectie bij het plakken.
Gelieve slechts één cel te kiezen.</translation>
    </message>
    <message>
      <source>Copy &amp; Paste failed</source>
      <translation>Kopiëren en plakken mislukt</translation>
    </message>
    <message>
      <source>Alias contains invalid characters!</source>
      <translation>Alias bevat ongeldige tekens!</translation>
    </message>
    <message>
      <source>Refer to cell by alias, for example
Spreadsheet.my_alias_name instead of Spreadsheet.B1</source>
      <translation>Verwijs naar cel met een alias, bijvoorbeeld
Spreadsheet.mijn_alias_naam in plaats van Spreadsheet.B1</translation>
    </message>
  </context>
  <context>
    <name>QtColorPicker</name>
    <message>
      <source>Black</source>
      <translation>Zwart</translation>
    </message>
    <message>
      <source>White</source>
      <translation>Wit</translation>
    </message>
    <message>
      <source>Red</source>
      <translation>Rood</translation>
    </message>
    <message>
      <source>Dark red</source>
      <translation>Donkerrood</translation>
    </message>
    <message>
      <source>Green</source>
      <translation>Groen</translation>
    </message>
    <message>
      <source>Dark green</source>
      <translation>Donkergroen</translation>
    </message>
    <message>
      <source>Blue</source>
      <translation>Blauw</translation>
    </message>
    <message>
      <source>Dark blue</source>
      <translation>Donkerblauw</translation>
    </message>
    <message>
      <source>Cyan</source>
      <translation>Cyaan</translation>
    </message>
    <message>
      <source>Dark cyan</source>
      <translation>Donkercyaan</translation>
    </message>
    <message>
      <source>Magenta</source>
      <translation>Magenta</translation>
    </message>
    <message>
      <source>Dark magenta</source>
      <translation>Donkermagenta</translation>
    </message>
    <message>
      <source>Yellow</source>
      <translation>Geel</translation>
    </message>
    <message>
      <source>Dark yellow</source>
      <translation>Donkergeel</translation>
    </message>
    <message>
      <source>Gray</source>
      <translation>Grijs</translation>
    </message>
    <message>
      <source>Dark gray</source>
      <translation>Donkergrijs</translation>
    </message>
    <message>
      <source>Light gray</source>
      <translation>Lichtgrijs</translation>
    </message>
    <message>
      <source>Custom Color</source>
      <translation>Aangepaste kleur</translation>
    </message>
  </context>
  <context>
    <name>Sheet</name>
    <message>
      <source>Form</source>
      <translation>Vorm</translation>
    </message>
    <message>
      <source>&amp;Content:</source>
      <translation>&amp;Inhoud:</translation>
    </message>
    <message>
      <source>&amp;Alias:</source>
      <translation>&amp;Alias:</translation>
    </message>
    <message>
      <source>Refer to cell by alias, for example
Spreadsheet.my_alias_name instead of Spreadsheet.B1</source>
      <translation>Verwijs naar cel met een alias, bijvoorbeeld
Spreadsheet.mijn_alias_naam in plaats van Spreadsheet.B1</translation>
    </message>
  </context>
  <context>
    <name>SpreadsheetGui::Module</name>
    <message>
      <source>Unnamed</source>
      <translation>Naamloos</translation>
    </message>
  </context>
  <context>
    <name>SpreadsheetGui::SheetTableView</name>
    <message>
      <source>Insert rows</source>
      <translation>Rijen invoegen</translation>
    </message>
    <message>
      <source>Remove rows</source>
      <translation>Rijen verwijderen</translation>
    </message>
    <message>
      <source>Insert columns</source>
      <translation>Kolommen invoegen</translation>
    </message>
    <message>
      <source>Remove columns</source>
      <translation>Kolommen verwijderen</translation>
    </message>
    <message>
      <source>Properties...</source>
      <translation>Eigenschappen...</translation>
    </message>
  </context>
  <context>
    <name>Workbench</name>
    <message>
      <source>Spreadsheet</source>
      <translation>Rekenblad</translation>
    </message>
  </context>
</TS>
